Monty Python's Flying Circus: Just the Words - Episode 25

# Episode Twenty-five

'The Black Eagle'
Dirty Hungarian phrasebook
Court (phrasebook)
Communist quiz
'Ypres 1914' - abandoned
Art gallery strike
'Ypres 1914'
Hospital for over-actors
Gumby flower arranging
Spam

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Close up of a flag bearing a black eagle on a red background fluttering in the wind. Blue sky behind and scudding clouds. Adventure music as for buccaneer film.
| Captions:
| THE BLACK EAGLE CAST BLACK EAGLE.................THORNTON WELLES MEG FAIRWEATHER.............KATE TAMBLYING JACK FAIRWEATHER............OWEN TREGOWER HENRY FAIRWEATHER...........RUSS TEMPOLE JNR. MRS FAIRWEATHER.............ALICE SHOEMAKER DR TENNYSON.................MARSHALL M. WEST LUMPKIN.....................DINO DE VERE MR RIVERS...................WALTER SCHENKEL LT STAVEACRE................NORMAN S. HUGHES A WENCH............. .......MARSHA SUTTON SECOND WENCH................TINEA PEDIS THE DOG.....................KARL SCREENPLAY BY AL R. SCHROEDER AND WAYNE KOPIT BASED ON THE NOVEL 'THE BLUE EAGLE' BY RAPHAEL SABATINI SET DECORATION..............CY BORGINI MAKE-UP.....................BRUCE DILKES COSTUMES....................JOAN LOUIS UNIT MANAGER................TREVOR BELOWSKI CONTINUITY..................SUE CARPENTER SPECIAL EFFECTS.............WALTER SCHENKEL MISS TAMBLYING'S GOWNS BY HEPWORTHS COLOUR BY CHROMACOLOUR SOUND RECORDING WCA SYSTEM COPYRIGHT BY SCHENKEL PRODUCTIONS ANY SIMILARITY BETWEEN PERSONS LIVING OR DEAD IS CONICIDENTAL PRODUCED BY JOSEPH M. SCHLACK DIRECTED BY LAUREN F. NORDER
| Mix through from flag to sea at night. Sound of water lapping. Soft sound of muffled oars drawing nearer. We can see a rowing boat making slowly and silently towards the shore where the camera is. The stirring music continues. ROLLER CAPTION: 'IN 1742 THE SPANISH EMPIRE LAY IN RUINS. TORN BY INTERNAL DISSENT, AND WRACKED BY NUMEROUS WARS, ITS RICH TRADE ROUTES FELL EASY PREY TO BRITISH PRIVATEERS...AND THE TREASURE OF THE SPANISH MAIN WAS BROUGHT HOME TO THE SHORES OF ENGLAND' By the time roller captions have finished the rowing boat has approached much nearer. It stops and they ship their oars. Cut in to close ups of pirate's face peering into the darkness. Shot from the boat of a deserted cliff top. A light flashes twice. Then there is a pause. Cut back to the boat; the men look uneasy as they wait for the third flash. Cut back to the cliff...at last the third flash. Cut back to the boat; they start to again. Cut to them beaching the boat on the shore. They start to unload sacks and chests. Putting them onto their shoulders they start to walk along the shore line. We pan with them for quite some way...and suddenly between the camera and the pirates we come across the announcer at a desk. He wears a dinner jacket and shuffles some papers in front of him.
Announcer | And now for something completely different...
It's Man | It's...
| Animated titles. Cut to a small tobacconist's shop. The tobacconist is handing change to a fireman.
Fireman | Thank you very much for the change, Mr Tobacconist. (he exits; then out of vision, very loud) Was that all right?
Everybody | SSSh!
| Stirring adventure music of buccaneer film as at the beginning and the roller caption in the same typeface. ROLLER CAPTION: IN 1970, THE BRITISH EMPIRE LAY IN RUINS, FOREIGN NATIONALS FREQUENTED THE STREETS - MANY OF THEM HUNGARIANS (NOT THE STREETS - THE FOREIGN NATIONALS). ANYWAY, MANY OF THESE HUNGARIANS WENT INTO TOBACCONIST'S SHOPS TO BUY CIGARETTES... Enter Hungarian gentleman with phrase book. He is looking for the right phrase.
Hungarian | I will not buy this record, it is scratched.
Tobacconist | Sorry?
Hungarian | I will not buy this record, it is scratched.
Tobacconist | No, no, no.This ... tobacconist's.
Hungarian | Ah! I will not buy this tobacconist's, it is scratched.
Tobacconist | No, no, no ...tobacco...er, cigarettes?
Hungarian | Yes, cigarettes. My hovercraft is full of eels.
Tobacconist | What?
Hungarian | (miming matches) My hovercraft is full of eels.
Tobacconist | Matches, matches? (showing some)
Hungarian | Yah, yah. (he takes cigarettes and matches and pulls out loose change; he consults his book) Er, do you want ... do you want to come back to my place, bouncy bouncy?
Tobacconist | I don't think you're using that right.
Hungarian | You great pouf.
Tobacconist | That'll be six and six, please.
Hungarian | If I said you had a beautiful body, would you hold it against me? I am no longer infected.
Tobacconist | (miming that he wants to see the book; he takes the book) It costs six and six ...(mumbling as he searches) Costs six and six ... Here we are ... Yandelvayasna grldenwi stravenka.
| Hungarian hits him between the eyes. Policeman walking along the street suddenly stops and puts his hand to his ear. He starts running down the street, round corner and down another street, round yet another corner and down another street into the shop
Policeman | What's going on here then?
Hungarian | (opening book and pointing at tobacconist) You have beautiful thighs.
Policeman | What?
Tobacconist | He hit me.
Hungarian | Drop your panties, Sir William, I cannot wait till lunchtime.
Policeman | Right! (grabs him and drags him out)
Hungarian | My nipples explode with delight.
| Cut to a courtroom.
Clerk | Call Alexander Yahlt
Voices | Call Alexander Yahlt. Call Alexander Yahlt. Call Alexander Yahlt. (They do this three times finishing with harmony)
Magistrate | Oh, shut up.
Clerk | You are Alexander Yahlt?
Yahlt | (Derek Nimmo's voice (dubbed on)) Oh I am.
Clerk | Skip the impersonations. You are Alexander Yahlt?
Yahlt | (normal voice) I am.
Clerk | You are hereby charged that on the 28th day of May 1970, you did wilfully, unlawfully, and with malice aforethought publish an alleged English-Hungarian phrasebook with intent to cause a breach of the peace. How do you plead?
Yahlt | Not guilty.
Clerk | You live at 46, Horton Terrace?
Yahlt | I do live at 46, Horton Terrace.
Clerk | You are the director of a publishing company?
Yahlt | I am the director of a publishing company.
Clerk | Your company publishes phrasebooks?
Yahlt | My company does publish phrasebooks.
Clerk | You did say 46, Horton Terrace, didn't you?
Yahlt | Yes.
| He claps his hand to his mouth; gong sounds - general applause.
Clerk | Ha, ha, ha, I got him.
Magistrate | Get on with it! Get on with it!
Clerk | Yes, m'lud, on the 28th of May, you published this phrasebook.
Yahlt | I did.
Clerk | I quote an example. The Hungarian phrase meaning 'Can you direct me to the station?' is translated by the English phrase, 'Please fondle my bum'.
Yahlt | I wish to plead incompetence.
| The policeman stands up
Policeman | Please may I ask for an adjournment, m'lud?
Magistrate | An adjournment? Certainly not. (the policeman sits down; there is a loud raspberry; the policeman goes bright red) Why on earth didn't you say why you wanted an adjourment?
Policeman | I didn't know an acceptable legal phrase, m'lud.
| Cut to stock film of Women's Institute applauding. Cut back to the magistrate.
Magistrate | If there's any more stock film of women applauding, I'll clear the court.
Clerk | Call Abigail Tesler
| Two policemen carry a large photo blow-up the size of a door. It is a photo from a newspaper like the 'Mirror', with a girl in a bikini and the headline across the top: 'Sunshine Sizzler'. Underneath is some small print which is later read out (see below). They prop her up in the witness box.
Defence | M'lud - this is Abigail Tesler.
Magistrate | Is it?
Defence | Yes, m'lud. Twenty-three-year-old Abigail hails from down under, where they're upside down about her. Those Aussies certainly know a thing or two when it comes to beach belles. Bet some life-saver wouldn't mind giving her the kiss of life. So watch out for sharks, Abigail!
| Cut back to the judge's desk. The judge has turned into a similar photo blow-up of himself, the size of a door. The headline at the top is 'Legal Sizzler'.
Journalist | (voice over) Is this strictly releveant? Quizzed learned lovely, Justice Maltravers. Seventy-eight-year-old Justice hails from Esther, and he's been making a big name for himself at the recent Assizes at Exeter. (cut back to defence counsel, who has turned into a large photo blow-up of himslef headed 'Defence Counsel Sizzler')
Voice Over | All will be revealed soon m'lud, quipped tall forty-two-year-old Nelson Bedowes. Cutie QC Nelson's keen on negligence and grievous bodily harm at Gray's Inn. And with cases like he's won we bet Gray's in when Nelson's around.
| ANIMATION: Starting with newspaper photo of judge in dark glasses and full wig with a starlet beside him, walking down London airport departure corridor carrying cases.
Voice Over | Well get on with it, admitted seventy-eight-year-old genial jurisprude Maltravers seen here at London airport, on his way to judge for Britain at the famous International Court in the Hague ...
Voice | Get off!
| CAPTION: 'WORLD FORUM'
| An important-looking current affairs set. On the back wall behind the presenter huge letters say: 'World Forum'
Presenter | Good evening. Tonight is indeed a unique occasion in the history of television. We are very privileged, and deeply honoured to have with us in the studio, Karl Marx, founder of modern socialism, and author of the 'Communist Manifesto'. (Karl Marx is sitting at a desk; he nods) Vladimir Ilich Ulyanov, better known to the world as Lenin, leader of the Russian Revolution, writer, statesman, and father of modern communism. (shot of Lenin also at desk; he nods) Che Guevara, the Cuban guerrilla leader. (shot of Guevara) And Mao Tse-tung, leader of the Chinese Communist Party since 1949. (shot of Mao; the presenter picks up a card) And the first question is for you, Karl Marx. The Hammers - The Hammers is the nickname of what English football team? 'The Hammers? (shot of Karl Marx furrowing his brow- obviously he hasn't a clue) No? Well bad luck there, Karl. So we'll go onto you Che. Che Guevara - Coventry City last won the FA Cup in what year? (cut to Che looking equally dumbfounded) No? I'll throw it open. Coventry City last won the FA Cup in what year? (they all look blank) No? Well, I'm not surprised you didn't get that. It was in fact a trick question. Coventry City have never won the FA Cup. So with the scores all equal now we go onto our second round, and Lenin it's your starter for ten. Teddy Johnson and Pearl Carr won the Eurovision Song Contest in 1959. What was the name of the song? ... Teddy Johnson and Pearl Carr's song in the 1959 Eurovision Song Contest? Anybody? (buzzer goes as in 'University Challenge'.' zoom in on Mao Tse-tung) Yes, Mao Tse-tung?
Mao Tse-tung | 'Sing Little Birdie'?
Presenter | Yes it was indeed. Well challenged. (applause) Well now we come on to our special gift section. The contestant is Karl Marx and the prize this week is a beautiful lounge suite. (curtains behind the presenter sweep open to reveal a beautiful lounge suite; terrific audience applause; Karl comes out and stands in front of this display) Now Karl has elected to answer questions on the workers control of factories so here we go with question number one. Are you nervous? (Karl nods his head; the presenter reads from a card) The development of the industrial proletariat is conditioned by what other development?
Karl | The development of the industrial bourgeoisie. (applause)
Presenter | Yes, yes, it is indeed. You're on your way to the lounge suite, Karl. Question number two. The struggle of class against class is a what struggle? A what struggle?
Karl | A political struggle.
| Tumultuous applause
Presenter | Yes, yes! One final question Karl and the beautiful lounge suite will be yours... Are you going to have a go? (Karl nods) You're a brave man. Karl Marx, your final question, who won the Cup Final in 1949?
Karl | The workers' control of the means of production? The struggle of the urban proletariat?
Presenter | No. It was in fact, Wolverhampton Wanderers who beat Leicester 3-1.
| Cut to stock film of goal bring scored in a big football match. Roar from crowd. Stock footage of football crowds cheering.
Voice Over | (and CAPTION:) 'IN WORLD FORUM TODAY: KARL MARX, CHE GUEVARA, LENIN AND MAO TSE-TUNG. NEXT WEEK, FOUR LEADING HEADS OF STATE OF THE AFRO-ASIAN NATIONS AGAINST BRISTOL ROVERS AT MOLINEUX'
| ANIMATION: Sketch leading to stock drawing of First World War trench scene - barbed wire against the sky with a helmet stuck on a bayonet.
Voice Over | (and CAPTION:) 'IN 1914, THE BALANCE OF POWER LAY IN RUINS. EUROPE WAS PLUNGED INTO BLOODY CONFLICT. NATION FOUGHT NATION. BUT NO NATION FOUGHT NATION MORELY THAN THE ENGLISH HIP HIP HOORARY! NICE, NICE YAH BOO. PHILLIPS IS A GERMAN AND HE HAVE MY PEN'
Different Voice Over | (and CAPTION:) 'START AGAIN'
Voice Over | (and CAPTION:) 'IN 1914, THE BALANCE OF POWER LAY IN RUINS...'
| Mix through to close up of a harmonica bring played by a British Tommy.
| CAPTION: 'YPRES 1914'
| The camera pulls slowly out, with the plaintive harmonica still playing, to reveal the interior of a bunker in the trenches. Sitting around on old ammunition boxes etc. are the harmonica player, Private Jenkins, Sergeant Jackson, a padre with no arms, a sheikh, a Viking warrior, a male mermaid, a nun, a milkman and a Greek Orthodox priest. Sounds of warfare throughout, shells thudding, explosions etc.
Sergeant | (looking round rather uncomfortably at the strange collection) Jenkins?
Jenkins | (equally uncomfortable about playing such a tender scene in front of sheiks etc.) Yes, sir.
Sergeant | What are you going to do when you get back to Blighty?
Jenkins | I dunno, sarge... I expect I'll be looking after me mum. She'll be getting on a bit now.
Sergeant | Got a family of your own 'ave you?
Jenkins | No, she's ... she's all I got left now. My wife, Doreen ... she ... I got a letter.
Sergeant | You don't have to tell me, son.
Jenkins | No, sarge, I'd like to tell you, see this place....
| Cut to long shot of bunker. Floor manager strides on to set.
Floor Manager | Hold it. Hold it. Look, loves ... can anyone not involved in this scene, please leave the set. (he starts to herd out anyone not in First War costume) Now! Come on please. Anyone not concerned in this scene, the canteen's open upstairs. (sheikh, male mermaid etc. troop off) Now come on please. (to soldiers) Sorry loves. Sorry. We'll have to take it again, from the top. All fight. OK... Cue!
| Back to identical shot of harmonica-playing tommy; he plays a few bars.
| CAPTION: 'KNICKERS 1914'
| Cut to long shot. The floor manager rushes on again. The caption remains superimposed.
Floor Manager | Hold it. Hold it. Now, who changed the caption? Can whoever changed the caption put the right one back immediately please.
| CAPTION: 'YPRES 1914'
Floor Manager | Right. All right, we'll take it again from the top. Cue. (back to identical shot of harmonica-playing tommy with caption superimposed; slow pull out as before, then floor manager rushes on again) Hold it. Hold it. (he goes behind some sandbags looking extremely irritated) Come on. Come on, out of there. (he hauls a spaceman and hustles him off the set) You're not in this ... you're only holding the whole thing up. (turning to studio as a whole) Come on please. It's no good, loves. It's no good. We'll have to leave it for now. Come back when everyone's settled down a bit. So-that means we go over to the Art Room, all right. So cue camera three! (cut to Che Guevara caught in a hot embrace with Karl Marx) Sorry, camera four.
| Cut to Art Gallery. A large sign says: 'Italian Masters of the Renaissance'. Two art critics wandering through. They stop in front of a large Titian canvas. The canvas is about ten foot high by six foot wide.
First Critic | Aren't they marvelous? The strength and boldness... life and power in those colours.
Second Critic | This must be Titian's masterpiece.
First Critic | Oh indeed - if only for the composition alone. The strength of those foreground figures ... the firmness of the line...
Second Critic | Yes, the confidence of the master at the height of his powers.
| At this point a man in a country smock and straw hat and a straw in his mouth comes up to the painting and with a very businesslike manner presses the nipple of a nude in the painting. Ding dong sound of a front doorbell. He stands tapping his feet and whistling soundlessly beside the painting. He nods at the critics. Cut to the top of the painting to see that one of the figures has disappeared leaving a blank. The camera pans down the painting as we hear footsteps; as if coming down a lot of stone steps. Eventualy the camera comes to rest beside where the country bumpkin is standing and a door opens in the painting. We do, not see who has opened it, but can assume it is the cherub.
Cherub | Yes?
Bumpkin | Hello sonny, your dad in?
Cherub | Yes.
Bumpkin | Could I speak to him please? It's the man from 'The Hay Wain'.
Cherub | Who?
Bumpkin | The man from 'The Hay Wain' by Constable.
Cherub | Dad... it's the man from 'The Hay Wain' by Constable to see you.
Solomon | Coming.
| Sound of footsteps. Cut to another close up on the painting and we see the main figure disappearing. This figure suddenly puts his head round the door.
Solomon | Hello? How are you? Come on in.
Bumpkin | No, no can't stop, just passing by, actually.
Solomon | Oh, where are you now?
Bumpkin | Well may you ask. We just been moved in next to a room full of Brueghels ... terrible bloody din. Skating all hours of the night. Anyway, I just dropped in to tell you there's been a walk-out in the Impressionists.
Solomon | Walk-out, eh?
Bumpkin | Yeah. It started with the 'Déjeuner Sur L'Herbe' lot, evidently they were moved away from above the radiator or something. Anyway, the Impressionists are all out. Gainsborough's Blue Boy's brought out the eighteenth-century English portraits, the Flemish School's solid, and the German woodcuts are at a meeting now.
Solomon | Right. Then I'll get the Renaissance School out.
Bumpkin | OK, meeting 4.30 - 'Bridge at Arles'.
Solomon | OK, cheerio - good luck, son.
Bumpkin | OK.
| The door shuts and we hear Solomon's voice over.
Solomon | Right - everybody out.
| We see various famous paintings whose characters suddenly disappear.
Voices | I'm off. I'm off. I'm off, dear. (etc.)
| Mix through to front room of a suburban house. A man is sawing his wife in two in the classic long box.
Radio | Here is the News... (the man pauses for a moment and looks at radio, then resumes sawing; we zoom in to close up on the radio. There is a window behind it; as the radio talks, a group of paintings with picket signs pass by) by an almost unanimous vote, paintings in the National Gallery voted to continue the strike that has emptied frames for the last week. The man from Constable's 'Hay Wain' said last night that there was no chance of a return to the pictures before the weekend. Sir Kenneth Clarke has said he will talk to any painting if it can help bring a speedy end to the strike (a ghastly scream out of vision; the sawing stops abruptly) At Sotheby's, prices dropped dramatically as leading figures left their paintings. (Cut to Sotheby's)
Auctioneer | What am I bid for Vermeer's 'Lady Who Used to be at a Window'? Do I hear two bob?
Voice | Two bob!
Auctioneer | Gone. Now what am I bid for another great bargain? Edward Landseer's 'Nothing at Bay'.
| Pull out to reveal man standing beside auctioneer with the painting (the stag is missing). Cut to a group of famous characters from famous paintings who are clustered round the camera. Botticelli's Venus is in the centre jabbing her fingers at camera.
Venus | All we bloody want is a little bit of bloody consultation.
| Fade sound of them all shouting and jostling etc. Bring up sound of radio out of vision.
Radio | At a mass meeting at Brentford Football Ground, other works of art voted to come out in support of the paintings. (still in animation cut to Brentford football ground with famous statues in the stands) The vote was unanimous. (they all put their hands up) with one abstention. (cut to close up of 'Venus De Milo'; cut to TV Centre and slow zoom in) Meanwhile, at Television Centre work began again on a sketch about Ypres. A spokesman for the sketch said: he fully expected it to be more sensible this time.
| Cut to usual opening shot of close up of harmonica being played by tommy. CAPTION: YPRES 1914 Slow zoom out to reveal set-up as before with no extraneous characters.
Sergeant | Jenkins.
Jenkins | Yes, sarge?
Sergeant | What are you going to do when you get back to Blighty?
Jenkins | I dunno, sarge. I expect I'll look after my mum. She'll be getting on a bit now.
Sergeant | Got a family of your own, have you?
Jenkins | No - she's all I got left now. My wife, Doreen ... she... I got a letter.
Sergeant | You don't have to tell me, son.
Jenkins | No, sarge, I'd like to tell you. You see, this bloke from up the street...
| Enter a young major.
Major | OK, chaps, at ease. I've just been up the line...
Sergeant | Can we get through, sir?
Major | No, I'm afraid we'll have to make a break for it at nightfall.
Sergeant | Right, sir. We're all with yer.
Major | Yes I know, that's just the problem, sergeant. How many are there of us?
Sergeant | Well there's you, me, Jenkins, Padre, Kipper, there's five, sir.
Major | And only rations for...
Sergeant | Four, sir.
Major | Precisely. I'm afraid one of us will have to take the 'other' way out.
| Crash zoom into revolver which the major has brought out. Jarring chord. Close up of faces looking tense from one to the other. Tense music.
Padre | I'm a gonner, major. Leave me, I'm ... I'm not a complete man anymore.
Major | You've lost both your arms as well.
Padre | Yes. Damn silly really.
Major | No, no, we'll draw for it. That's the way we do things in the army. Sergeant, the straws!
| The sergeant gives him the straws. The major arranges them and hands them round.
Major | Right now, the man who gets the shortest straw knows what to do
| They all take the long straws. Including the padre who takes one in his teeth. The major is left with a tiny straw. A pause.
Sergeant | Looks like you, sir.
Major | Is it? What did we say, the longest straw was it?
Sergeant | No, shortest, sir.
Major | Well we'd better do it again, there's obviously been a bit of a muddle. (they do it again and the same thing happens) Oh dear. Best of three? (they go through it again and he gets left with it again) Right, well I've got the shortest straw. So I decide what means we use to decide who's going to do... to... to... to er .... to do the thing ... to do the right thing. Now rank doesn't enter into this, but obviously if I should get through the lines, I will be in a very good position to recommend anyone, very highly, for a posthumous VC. (he looks round to see if there are any takers) No? Good. Fine. Fine. Fine. Fine. Right. (counting out) Dip, dip, dip, my little ship sails on the ocean, you are (comes back to himself)... no wait, wait a minute, no I, I must have missed out a dip. I'll start again. Dip, dip, dip, dip, my little ship, sails on the ocean, you are ... (it's back on him again) No, this is not working out. It's not working out. What shall we do?
Jenkins | How about one potato, two potato, sir?
Major | Don't be childish, Jenkins. No, I think, I think fisties would be best. OK, so hands behind backs. After three, OK, one, two, three. (everyone except the padre who has no arms puts out clenched fist) Now what's this... stone, stone, stone, (looks down at his hand) and scissors. Now. Scissors cut everything, don't they?
Sergeant | Not stone, sir.
Major | They're very good scissors (then he suddenly sees the padre) Padre hasn't been!
Sergeant | No arms, sir.
Major | Oh, I'm terribly sorry, I'm afraid I didn't... tell you what. All those people who don't want to stay here and shoot themselves raise their arms.
Padre | Stop it! Stop it! Stop this ... this hideous façade.
Sergeant | Easy, padre!
Padre | No, no, I must speak. When I, when I came to this war, I had two arms, two good arms, but when the time came to... to lose one, I .. I gave it gladly, I smiled as they cut if off, (music under: 'There'll Always Be An England) because I knew there was a future for mankind. I ... I knew there was hope... so long as men were prepared to give their limbs (emotionally) And when the time came for me to give my other arm I... I gave it gladly. I... I sang as they sawed it off. Because I believed... (hysterically) Oh you may laugh, but I believed with every fibre of my body, with every drop of rain that falls, a... a flower grows. And that flower, that small fragile, delicate flower... (two modern-day ambulance attendants come in with a trolley which they put the padre onto and wheel him away; he is still going on)... shall burst forth and give a new life. New strength! (cut to a present-day ambulance racing out of TV Centre in speeded-up motion; it man through the streets, and arrives at the casualty entrance of a hospital; the doors swing open and the padre is rushed out on stretcher (still in fast motion) totally under a blanket; we hear his voice) ... freedom. Freedom from fear and freedom from oppression. Freedom from tyranny. (the camera picks up on sign which reads: 'Royal Hospital for Over-acting) A world where men and women of all races and creeds can live together in communion and then in the twilight of this life, our children, and our children's children and . .. (by this time he has disappeared in through the doors of the hospital)
| Cut to the interior of hospital and see specialist as he walks down a corridor.
Specialist | All our patients here are suffering from severe over-acting. (a nurse goes past leading a Long John Silver who keeps going 'Aha! Jim Lad') When they're brought in they're all really over the top. (he passes a whole group of Long John Silvers) And it's our job to try and treat the condition of over-acting ... (he passes a group of King Rats, and indicates the worst case) rather serious. (he walks on through a door) This is the Richard III Ward.
| Pull out to reveal a crowd of Richard III's. The specialist indicates one who is really over the top.
Richard III | A horse. A horse. My kingdom for a horse.
Specialist | Most of these cases are pretty unpleasant. Nurse... (a nurse comes in and sedates Richard III) But the treatment does work with some people. This chap came to us straight from the Chichester Festival; we operated just in time, and now he's almost normal.
| He walks over to a very ordinary Richard III, who smiles disarmingly and says quite chatlily
Second Richard | A horse, a horse, my kingdom for a horse.
| Shaking his head sadly, the specialist leaves the ward and opens a door to another one.
Specialist | But in here we have some very nasty cases indeed.
| ANIMATION: involving grotesque Hamlets.
Hamlets | To be or not to be. That is the question. To be...
| Animation leads to close up of flowers.
| SUPERIMPOSED CAPTION: 'FLOWER ARRANGMENT'
| Pull back to show Gumby in studio with piles of flowers on a table.
| SUPERIMPOSED CAPTION: 'INTRODUCED BY D. P. GUMBY'
Gumby | Good evening. First take a bunch of flowers. (he grabs flowers from the table) Pretty begonias, irises, freesias and cry-manthesums...then arrange them nicely in a vase. (he thrusts the flowers head downwards into the vase and stuffs them in wildly; he even bangs them with a mallet in an attempt to get them all in) Get in! Get in! Get in!
| Cut to a cafe. All the customers are Vikings. Mr and Mrs Bun enter - downwards (on wires)
Mr Bun | Morning
Waitress | Morning
Mr Bun | What have you got, then?
Waitress | Well, there's egg and bacon; egg sausage and bacon; egg and spam; egg, bacon and spam; egg, bacon, sausage and spam; spam, bacon, sausage and spam; spam, egg, spam, spam, bacon and spam; spam, spam, spam, egg and spam; spam, spam, spam, spam, spam, spam, baked beans, spam, spam, spam and spam; or Lobster thermidor aux crevettes with a mornay sauce garnished with truffle pâté, brandy and with a fried egg on top and spam.
Mrs Bun | Have you got anything without spam in it?
Waitress | Well, there's spam egg sausage and spam, that's not got much spam in it.
Mrs Bun | I don't want ANY spam!
Mr Bun | Why can't she have egg, bacon, spam and sausage?
Mrs Bun | That's got spam in it!
Mr Bun | Not as much as spam, egg, sausage and spam.
Mrs Bun | Look, could I have egg, bacon, spam and sausage without the spam.
Waitress | Uuuuuuggggh!
Mrs Bun | What d'you mean uuugggh! I don't like spam
Vikings | (singing) Spam, spam, spam, spam, spam ... spam, spam, spam, spam ... lovely spam, wonderful spam ...
| Brief stock shot of a Viking ship.
Waitress | Shut up. Shut up! Shut up! You can't have egg, bacon, spam and sausage without the spam.
Mrs Bun | Why not!
Waitress | No, it wouldn't be egg, bacon, spam and sausage, would it.
Mrs Bun | I don't like spam!
Mr Bun | Don't make a fuss, dear. I'll have your spam. I love it. I'm having spam, spam, spam, spam, spam ...
Vikings | (singing) Spam, spam, spam, spam ...
Mr Bun | ... baked beans, spam, spam and spam.
Waitress | Baked beans are off.
Mr Bun | Well can I have spam instead?
Waitress | You mean spam, spam, spam, spam, spam, spam, spam, spam, spam, spam?
Vikings | (still singing) Spam, spam, spam, spam ... (etc.)
Mr Bun | Yes.
Waitress | Arrggh!
Vikings | .. . lovely spam, wonderful, spam.
Waitress | Shut up! Shut up!
| The Vikings shut up momentarily. Enter the hungarian.
Hungarian | Great boobies, honeybun, my lower intestine is full of spam, egg, spam, bacon, spam, tomato, spam ...
Vikings | (starting up again) Spam, spam, spam, spam ...
Waitress | Shut up
| A policeman rushes in and bundles the Hungarian out. |
Hungarian | My nipples explode...
| Cut to a historian. SUPERIMPOSED CAPTION: 'A HISTORIAN' |
Historian | Another great Viking victory was at the Green Midget cafe at Bromley. Once again the Viking strategy was the same. They sailed from these fiords here, (indicating a map with arrows on it) assembled at Trondheim and waited for the strong north-easterly winds to blow their oaken galleys to England whence they sailed on May 23rd. Once in Bromley they assembled in the Green Midget cafe and spam selecting a spam particular spam item from the spam menu would spam, spam, spam, spam, spam ...
| The backdrop behind him rises to reveal the cafe again, The Vikings start singing again and the historian conducts them |
Vikings | (singing) Spam, spam, spam, spam, spam, lovely spam, wonderful spam. Lovely spam wonderful spam ...
| Mr and Mrs Bun rise slowly in the air
| SUPERIMPOSED CAPTION: 'IN 1970 MONTY PYTHON'S FLYING CIRCUS LAY IN RUINS, AND THEN THE WORDS ON THE SCREEN SAID:'
| Fade out and roll credits, which read: MONTY PYTHON'S FLYING CIRCUS WAS CONCEIVED, WRITTEN AND SPAM PERFORMED BY SPAM TERRY JONES MICHAEL SPAM PALIN JOHN SPAM JOHN SPAM JOHN SPAM CLEESE GRAHAM SPAM SPAM SPAM CHAPMAN ERIC SPAM EGG AND CHIPS IDLE TERRY SPAM SAUSAGE SPAM EGG SPAM GILLIAM ALSO APPEARING ON TOAST THE FRED TOMLINSON SPAM EGG CHIPS AND SINGERS RESEARCH PATRICIA HOULIHAN AND SAUSAGE MAKEUP PENNY PENNY PENNY AND SPAM NORTON COSTUMES EGG BAKED BEANS SAUSAGE AND TOMATO, OH, AND HAZEL PETHIG TOO ANIMATIONS BY TERRY (EGG ON FACE) GILLIAM FILM CAMERAMAN JAMES (SPAM SAUSAGE EGG AND TOMATO) BALFOUR (NOT SUNDAYS) FILM EDITOR RAY (FRIED SLICE AND GOLDEN THREE DELICIOUS) MILLICHOPE (SPAM EXTRA) SOUND CHIPS SAUSAGE LIVERWURST, PHEASANT, SPAM, NEWSAGENTS, CHIPS, AND PETER ROSE LIGHTING OTIS (SPAM'S OFF DEAR) EDDY DESIGNER ROBERT ROBERT ROBERT ROBERT BERK AND TOMATO PRODUCED BY IAN (MIXED GRILL) MACNAUGHTON 7/&D BBC SPAM TV SERVICE NOT INCLUDED |
Voice Over | Haagbard Etheldronga and his Viking hordes are currently appearing in 'Grin and Pillage it' at the Jodrell Theatre, Colwyn Bay. 'The Dirty Hungarian Phrase Book' is available from Her Majesty's Stationery Office, price - a kiss on the bum.
| Fade out. Fade in in Karl Marx and Che Guevara lying post-coitally in bed. Karl switches off the light. |